@@ -22,26 +22,39 @@ class MySQL(object):
             print(e.args)
 
     def query(self, sql):
+        result = None
         try:
             self.lock.acquire()
             self.cursor.execute(sql)
-            self.lock.release()
             result = self.cursor.fetchall()
             self.db.commit()
-            return result
         except Exception as e:
             print(e.args)
             self.db.rollback()
+        finally:
+            self.lock.release()
+            return result
+
+    def delete(self, sql):
+        try:
+            self.lock.acquire()
+            self.cursor.execute(sql)
+            self.db.commit()
+        except Exception as e:
+            print(e.args)
+            self.db.rollback()
+        finally:
+            self.lock.release()
 
     def save(self, item, table_name):
         self.db.ping(reconnect=True)
         data = dict(item)
         keys = ', '.join(data.keys())
         values = ', '.join(['%s'] * len(data))
-        sql = 'INSERT INTO {table} ({keys}) values ({values})'.format(table=table_name, keys=keys, values=values)
+        sql = 'INSERT IGNORE INTO {table} ({keys}) values ({values})'.format(table=table_name, keys=keys, values=values)
         try:
             self.lock.acquire()
-            if self.cursor.execute(sql, tuple(data.values()) * 2):
+            if self.cursor.execute(sql, tuple(data.values())):
                 self.db.commit()
         except pymysql.MySQLError as e:
             print(e.args)
